import numpy as np
import pandas as pd
def relative_intensity(matrix):
    
    
    """ 
	Docstring for function pyKrev.relative_intensity 
	====================
	This function takes a matrix of peak intensities and calculates the relative intensities for each column. 
    
	Use
	----
	relative_intensity(Y)
    
	Returns a numpy array of shape(Y) in which each value is the relative intensity of that column.  
    
	Parameters
	----------
	Y: A list or numpy array containing peak intensities.  
    
    
	Info
	----------
	Relative peak intensity is calculated by summing all the intensities given in a column of Y,
	and dividing each item in the column (i) by the sum. So that sum(i...n) = 1.  
        
    """  
    
    if isinstance(matrix,pd.DataFrame): #if the user has supplied a dataframe e.g. produced by ordination_matrix
        matrix = matrix.to_numpy()
    
    reshape = False
    if len(matrix.shape) == 1: #i.e. if the matrix is 1D
        matrix = np.reshape(matrix,(len(matrix),1)) #reshape to 2D 
        reshape = True 
    row, col = np.shape(matrix)
    transformed_matrix = np.zeros((row,col))
    for i in range(0,col):
        col_sum = sum(matrix[:,i])
        for x in range(0,row):
                transformed_matrix[x,i] = matrix[x,i] / col_sum
    if reshape == True: #if matrix provided as 1D
        transformed_matrix = np.reshape(transformed_matrix,(len(transformed_matrix),)) #reshape back to 1D
    return transformed_matrix


from .calculate_mass import calculate_mass
from .element_counts import element_counts
import numpy as np
def kendrick_mass_defect(formula_list,mz_list,base = ['CH2']):
    """ 
	Docstring for function pyKrev.kendrick_mass_defect
	====================
	This function takes a list of molecular formula and their corresponding mz_values and calculates kendrick mass defect scores.  
    
	Use
	----
	approximate mass(Y,X)
    
	Returns a tuple contains two numpy arrays of len(Y). The first contains the kendrickMass and the second contains the kendrickMassDefect.
    
	Parameters
	----------
	Y: A list of molecular formula. 
    X: A list of mz_values of len(Y). 
    
    Base: Atom group used to define the Kendrick mass.
    Info
	----------
    Calculation taken from Hughey et al (2001) 
    "Kendrick Mass Defect Spectrum: A Compact Visual Analysis for Ultrahigh-Resolution Broadband Mass Spectra"
    
    """
    
    #Formula and mz lists must be the same length
    assert(len(formula_list)==len(mz_list))
    if type(mz_list) == list:
        mz_list = np.array(mz_list)
    if type(base) != list:
        raise AssertionError("Base must be provided as a string within a list. E.g. ['CH2']")

    kendrickMass = np.empty(len(formula_list))
    kendrickMassDefect = np.empty(len(formula_list))

    nominalBase = calculate_mass(base, method = 'nominal')
    exactBase = calculate_mass(base, method = 'monoisotopic')
    kendrickMass = np.array(mz_list) * (nominalBase/exactBase)
    kendrickMassDefect  = np.around(kendrickMass) - kendrickMass
    
    return kendrickMass, kendrickMassDefect